@@ -13,17 +13,18 @@ from .api import DiGraph_visualization
 from .api import graph_features
 from .api import user_timeline_extraction
 from .api import advanced_features
-from .api import filter_possible_irregular_profiles
-from .api import evaluate_NLP_profiles
+from .api import abnormal_categories_profiles
+from .api import contextual_analysis_profiles
 from .api import general_pieChart
 from .api import distribution_sentiment_tweets
 from .api import terrorist_keywords_belonging
 from .api import pie_chart_keywords_terrorist
 from .api import terrorist_hashtags_belonging
 from .api import pie_chart_hashtags_terrorist
-from .api import NLP_analysis
+from .api import contextual_analysis_profile
 from .api import more_tweets_required
 from .api import profile_trend_visualization
 from .api import text_to_list_features_conversor
 from .api import profile_max_tw_day_hourly_visualization
-from .api import final_pieChart
\ No newline at end of file
+from .api import terrorist_tweets_classification_pieChart
+from .api import distribution_sentiment_terrorist_tweets
\ No newline at end of file
